# Hello
this is an example project demonstarting how to publish Python module to PyPI.
## installation
run the following to install:
>>>pip3 install hello
## Usage
form hello import hello
# Generate "hello"
hello()
# Generate 'hello from ajay'
